@@ -4,8 +4,6 @@
 #include <stdlib.h>
 #include "jellyfish.h"
 
-#define NOTNUM(c)   ((c>57) || (c<48))
-
 /* borrowed heavily from strcmp95.c
  *    http://www.census.gov/geo/msb/stand/strcmp.c
  */
@@ -40,8 +38,14 @@ double _jaro_winkler(const JFISH_UNICODE *ying, int ying_length,
     // ensure that neither string is blank
     if (!ying_length || !yang_length) return 0;
 
-    search_range = min_len = (ying_length > yang_length) ? ying_length : yang_length;
-
+    if (ying_length > yang_length) {
+        search_range = ying_length;
+        min_len = yang_length;
+    } else {
+        search_range = yang_length;
+        min_len = ying_length;
+    }
+  
     // Blank out the flags
     ying_flag = calloc((ying_length + 1), sizeof(JFISH_UNICODE));
     if (!ying_flag) {
@@ -105,11 +109,11 @@ double _jaro_winkler(const JFISH_UNICODE *ying, int ying_length,
     weight /=  3.0;
 
     // Continue to boost the weight if the strings are similar
-    if (winklerize && weight > 0.7 && ying_length > 3 && yang_length > 3) {
+    if (winklerize && weight > 0.7) {
 
         // Adjust for having up to the first 4 characters in common
         j = (min_len >= 4) ? 4 : min_len;
-        for (i=0; ((i<j) && (ying[i] == yang[i]) && (NOTNUM(ying[i]))); i++);
+        for (i=0; ((i<j) && (ying[i] == yang[i])); i++);
         if (i) {
             weight += i * 0.1 * (1.0 - weight);
         }
@@ -119,10 +123,8 @@ double _jaro_winkler(const JFISH_UNICODE *ying, int ying_length,
            the agreeing characters must be > .5 of remaining characters.
         */
         if ((long_tolerance) && (min_len>4) && (common_chars>i+1) && (2*common_chars>=min_len+i)) {
-            if (NOTNUM(ying[0])) {
-                weight += (double) (1.0-weight) *
-                    ((double) (common_chars-i-1) / ((double) (ying_length+yang_length-i*2+2)));
-            }
+            weight += (double) (1.0-weight) *
+                ((double) (common_chars-i-1) / ((double) (ying_length+yang_length-i*2+2)));
         }
     }
 
